==> reakit-0.14.6.tgz: package/es/Popover.js <==
import { b as _extends, d as _inheritsLoose, e as _assertThisInitialized, f as _defineProperty } from './chunk-fb907809.js';
import React__default from 'react';
import { findDOMNode } from 'react-dom';
import PropTypes__default from 'prop-types';
import { prop } from 'styled-tools';
import Popper from 'popper.js';
import styled from './styled.js';
import as from './as.js';
import Hidden from './Hidden.js';
import Box from './Box.js';
import { a as PopoverArrow } from './chunk-00dfa47e.js';
import { a as callAll } from './chunk-d8771a86.js';
import { a as HiddenContainer } from './chunk-5a36c0e0.js';
import { c as HiddenToggle, b as HiddenShow, a as HiddenHide } from './chunk-419da5e4.js';
import 'styled-components';
import '@emotion/is-prop-valid';
import 'hoist-non-react-statics';
import './chunk-a7ce379e.js';
import './Base.js';
import './chunk-254efadd.js';
import 'constate';
import './Arrow.js';

var HiddenBox = Hidden.as(Box);

var Component =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Component, _React$Component);

  function Component() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      placement: _this.props.placement,
      translateX: undefined,
      translateY: undefined,
      originX: undefined,
      originY: undefined
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "getPopover", function () {
      return findDOMNode(_assertThisInitialized(_assertThisInitialized(_this)));
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "modifier", function (data) {
      var placement = data.placement,
          offsets = data.offsets,
          arrowElement = data.arrowElement,
          arrowStyles = data.arrowStyles;
      var reference = offsets.reference,
          popper = offsets.popper;

      var _placement$split = placement.split("-"),
          position = _placement$split[0];

      var isVertical = ["top", "bottom"].indexOf(position) >= 0;
      var referenceCenter = isVertical ? reference.width / 2 : reference.height / 2;
      var side = isVertical ? "left" : "top";
      var sideValue = referenceCenter - popper[side];

      if (arrowElement) {
        var top = arrowStyles.top,
            left = arrowStyles.left;
        arrowElement.style.top = isVertical ? "" : top + "px";
        arrowElement.style.left = isVertical ? left + "px" : "";
      }

      _this.setState({
        originX: isVertical ? sideValue + "px - 50%" : 0,
        originY: !isVertical ? sideValue + "px - 50%" : 0,
        translateX: popper.left,
        translateY: popper.top,
        placement: data.placement
      });

      return data;
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "getOptions", function () {
      var _this$props = _this.props,
          placement = _this$props.placement,
          flip = _this$props.flip,
          shift = _this$props.shift;

      var popover = _this.getPopover();

      var arrowClassName = "." + PopoverArrow.styledComponentId;
      var arrow = popover.querySelector(arrowClassName);
      return {
        placement: placement,
        modifiers: {
          hide: {
            enabled: false
          },
          applyStyle: {
            enabled: false
          },
          arrow: {
            enabled: !!arrow,
            element: arrow
          },
          flip: {
            enabled: flip,
            padding: 16
          },
          shift: {
            enabled: shift
          },
          offset: {
            offset: "0, " + _this.props.gutter
          },
          setState: {
            enabled: true,
            order: 900,
            fn: _this.modifier
          }
        }
      };
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "initPopper", function () {
      if (!_this.popper) {
        var popover = _this.getPopover();

        _this.popper = new Popper(popover.parentNode, popover, _this.getOptions());
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "destroyPopper", function () {
      if (_this.popper) {
        _this.popper.destroy();

        _this.popper = undefined;
      }
    });

    return _this;
  }

  var _proto = Component.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.initPopper();
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    this.destroyPopper();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (prevProps.visible !== this.props.visible || prevProps.placement !== this.props.placement || prevProps.children !== this.props.children) {
      this.destroyPopper();
      this.initPopper();
    }
  };

  _proto.render = function render() {
    return React__default.createElement(HiddenBox, _extends({
      id: this.props.popoverId
    }, this.state, {
      "data-placement": this.state.placement,
      defaultSlide: this.state.placement.replace(/-.+$/, ""),
      defaultExpand: this.state.placement.replace(/-.+$/, ""),
      slideOffset: this.props.gutter
    }, this.props, {
      unmount: false
    }));
  };

  return Component;
}(React__default.Component);

var Popover = styled(Component).withConfig({
  displayName: "Popover",
  componentId: "zeqjxj-0"
})(["position:absolute;top:0;left:0;user-select:auto;cursor:auto;color:inherit;background-color:white;padding:1em;z-index:999;outline:0;will-change:transform;&[aria-hidden=\"false\"]{transition-timing-function:", ";}", ";"], prop("timing", "cubic-bezier(0.25, 0.1, 0.25, 1.5)"), prop("theme.Popover"));
Popover.propTypes = {
  placement: PropTypes__default.oneOf(["auto", "top", "right", "bottom", "left", "top-start", "right-start", "bottom-start", "left-start", "top-end", "right-end", "bottom-end", "left-end"]),
  flip: PropTypes__default.bool,
  shift: PropTypes__default.bool,
  gutter: PropTypes__default.oneOfType([PropTypes__default.number, PropTypes__default.string]),
  popoverId: PropTypes__default.string
};
Popover.defaultProps = {
  role: "group",
  placement: "bottom",
  hideOnEsc: true,
  flip: true,
  shift: true,
  gutter: 12
};
var Popover$1 = as("div")(Popover);

var id = -1;

var uniqueId = function uniqueId(prefix) {
  id += 1;
  return prefix ? "" + prefix + id : id;
};

var onMount = function onMount(_ref) {
  var setState = _ref.setState;
  setState({
    popoverId: uniqueId("popover")
  });
};

var PopoverContainer = function PopoverContainer(props) {
  return React__default.createElement(HiddenContainer, _extends({}, props, {
    onMount: callAll(onMount, props.onMount)
  }));
};

var Component$1 = function Component(props) {
  return React__default.createElement(HiddenToggle, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverToggle = styled(Component$1).withConfig({
  displayName: "PopoverToggle",
  componentId: "x0s51c-0"
})(["", ";"], prop("theme.PopoverToggle"));
PopoverToggle.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverToggle$1 = as("button")(PopoverToggle);

var Component$2 = function Component(props) {
  return React__default.createElement(HiddenShow, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverShow = styled(Component$2).withConfig({
  displayName: "PopoverShow",
  componentId: "hnl7om-0"
})(["", ";"], prop("theme.PopoverShow"));
PopoverShow.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverShow$1 = as("button")(PopoverShow);

var Component$3 = function Component(props) {
  return React__default.createElement(HiddenHide, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverHide = styled(Component$3).withConfig({
  displayName: "PopoverHide",
  componentId: "sc-1ogem6j-0"
})(["", ";"], prop("theme.PopoverHide"));
PopoverHide.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverHide$1 = as("button")(PopoverHide);

Popover$1.Arrow = PopoverArrow;
Popover$1.Container = PopoverContainer;
Popover$1.Toggle = PopoverToggle$1;
Popover$1.Show = PopoverShow$1;
Popover$1.Hide = PopoverHide$1;

export default Popover$1;

==> reakit-0.15.0.tgz: package/es/Popover.js <==
import { b as _extends, d as _inheritsLoose, e as _assertThisInitialized, f as _defineProperty } from './chunk-fb907809.js';
import React__default from 'react';
import { findDOMNode } from 'react-dom';
import PropTypes__default from 'prop-types';
import { theme } from 'styled-tools';
import Popper from 'popper.js';
import styled from './styled.js';
import as from './as.js';
import Hidden from './Hidden.js';
import { a as PopoverArrow } from './chunk-06d0bb8b.js';
import { a as callAll } from './chunk-d8771a86.js';
import { a as HiddenContainer } from './chunk-ac382c96.js';
import { c as HiddenToggle, b as HiddenShow, a as HiddenHide } from './chunk-6133b9c9.js';
import 'styled-components';
import '@emotion/is-prop-valid';
import 'hoist-non-react-statics';
import './chunk-a44fd1b3.js';
import './chunk-a7ce379e.js';
import './Box.js';
import 'constate';

var Component =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Component, _React$Component);

  function Component() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      placement: _this.props.placement,
      translateX: undefined,
      translateY: undefined,
      originX: undefined,
      originY: undefined
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "getPopover", function () {
      return findDOMNode(_assertThisInitialized(_assertThisInitialized(_this)));
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "modifier", function (data) {
      var placement = data.placement,
          offsets = data.offsets,
          arrowElement = data.arrowElement,
          arrowStyles = data.arrowStyles;
      var reference = offsets.reference,
          popper = offsets.popper;

      var _placement$split = placement.split("-"),
          position = _placement$split[0];

      var isVertical = ["top", "bottom"].indexOf(position) >= 0;
      var referenceCenter = isVertical ? reference.width / 2 : reference.height / 2;
      var side = isVertical ? "left" : "top";
      var sideValue = referenceCenter - popper[side];

      if (arrowElement) {
        var top = arrowStyles.top,
            left = arrowStyles.left;
        arrowElement.style.top = isVertical ? "" : top + "px";
        arrowElement.style.left = isVertical ? left + "px" : "";
      }

      _this.setState({
        originX: isVertical ? sideValue + "px - 50%" : 0,
        originY: !isVertical ? sideValue + "px - 50%" : 0,
        translateX: popper.left,
        translateY: popper.top,
        placement: data.placement
      });

      return data;
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "getOptions", function () {
      var _this$props = _this.props,
          placement = _this$props.placement,
          flip = _this$props.flip,
          shift = _this$props.shift;

      var popover = _this.getPopover();

      var arrowClassName = "." + PopoverArrow.styledComponentId;
      var arrow = popover.querySelector(arrowClassName);
      return {
        placement: placement,
        modifiers: {
          hide: {
            enabled: false
          },
          applyStyle: {
            enabled: false
          },
          arrow: {
            enabled: !!arrow,
            element: arrow
          },
          flip: {
            enabled: flip,
            padding: 16
          },
          shift: {
            enabled: shift
          },
          offset: {
            offset: "0, " + _this.props.gutter
          },
          setState: {
            enabled: true,
            order: 900,
            fn: _this.modifier
          }
        }
      };
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "initPopper", function () {
      if (!_this.popper) {
        var popover = _this.getPopover();

        _this.popper = new Popper(popover.parentNode, popover, _this.getOptions());
      }
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "destroyPopper", function () {
      if (_this.popper) {
        _this.popper.destroy();

        _this.popper = undefined;
      }
    });

    return _this;
  }

  var _proto = Component.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.initPopper();
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    this.destroyPopper();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (prevProps.visible !== this.props.visible || prevProps.placement !== this.props.placement || prevProps.children !== this.props.children) {
      this.destroyPopper();
      this.initPopper();
    }
  };

  _proto.render = function render() {
    return React__default.createElement(Hidden, _extends({
      id: this.props.popoverId
    }, this.state, {
      "data-placement": this.state.placement,
      defaultSlide: this.state.placement.replace(/-.+$/, ""),
      defaultExpand: this.state.placement.replace(/-.+$/, ""),
      slideOffset: this.props.gutter
    }, this.props, {
      unmount: false
    }));
  };

  return Component;
}(React__default.Component);

var Popover = styled(Component).withConfig({
  displayName: "Popover",
  componentId: "zeqjxj-0"
})(["position:absolute;top:0;left:0;user-select:auto;cursor:auto;z-index:999;will-change:transform;", ";"], theme("Popover"));
Popover.propTypes = {
  placement: PropTypes__default.oneOf(["auto", "top", "right", "bottom", "left", "top-start", "right-start", "bottom-start", "left-start", "top-end", "right-end", "bottom-end", "left-end"]),
  flip: PropTypes__default.bool,
  shift: PropTypes__default.bool,
  gutter: PropTypes__default.oneOfType([PropTypes__default.number, PropTypes__default.string]),
  popoverId: PropTypes__default.string
};
Popover.defaultProps = {
  role: "group",
  placement: "bottom",
  hideOnEsc: true,
  flip: true,
  shift: true,
  gutter: 12,
  opaque: true,
  palette: "white"
};
var Popover$1 = as("div")(Popover);

var id = -1;

var uniqueId = function uniqueId(prefix) {
  id += 1;
  return prefix ? "" + prefix + id : id;
};

var onMount = function onMount(_ref) {
  var setState = _ref.setState;
  setState({
    popoverId: uniqueId("popover")
  });
};

var PopoverContainer = function PopoverContainer(props) {
  return React__default.createElement(HiddenContainer, _extends({}, props, {
    onMount: callAll(onMount, props.onMount)
  }));
};

var Component$1 = function Component(props) {
  return React__default.createElement(HiddenToggle, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverToggle = styled(Component$1).withConfig({
  displayName: "PopoverToggle",
  componentId: "x0s51c-0"
})(["", ";"], theme("PopoverToggle"));
PopoverToggle.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverToggle$1 = as("button")(PopoverToggle);

var Component$2 = function Component(props) {
  return React__default.createElement(HiddenShow, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverShow = styled(Component$2).withConfig({
  displayName: "PopoverShow",
  componentId: "hnl7om-0"
})(["", ";"], theme("PopoverShow"));
PopoverShow.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverShow$1 = as("button")(PopoverShow);

var Component$3 = function Component(props) {
  return React__default.createElement(HiddenHide, _extends({
    "aria-expanded": props.visible,
    "aria-controls": props.popoverId,
    "aria-haspopup": true
  }, props));
};

var PopoverHide = styled(Component$3).withConfig({
  displayName: "PopoverHide",
  componentId: "sc-1ogem6j-0"
})(["", ";"], theme("PopoverHide"));
PopoverHide.propTypes = {
  popoverId: PropTypes__default.string,
  visible: PropTypes__default.bool
};
var PopoverHide$1 = as("button")(PopoverHide);

Popover$1.Arrow = PopoverArrow;
Popover$1.Container = PopoverContainer;
Popover$1.Toggle = PopoverToggle$1;
Popover$1.Show = PopoverShow$1;
Popover$1.Hide = PopoverHide$1;

export default Popover$1;
